pilas.atajos

Package pilas :: Module atajos |
[hide private]
[frames] | no frames]

# Source Code for Module pilas.atajos

     1  # -*- encoding: utf-8 -*-
     2  # pilas engine - a video game framework.
     3  #
     4  # copyright 2010 - hugo ruscitti
     5  # license: lgplv3 (see http://www.gnu.org/licenses/lgpl.html)
     6  #
     7  # website - http://www.pilas-engine.com.ar
     8
     9  import pilas
    10  import subprocess
    11
    12  fabricar = pilas.actores.utils.fabricar
    13
    14 -def crear_grupo(*k):
    15      """Genera un grupo."""
    16      return pilas.grupos.Grupo(k)
    17
    18 -def definir_gravedad(x, y):
    19      """Define la gravedad del motor de física.
    20
    21      :param x: Aceleración horizontal.
    22      :param y: Aceleración vertical.
    23      """
    24      pilas.escena_actual().fisica.definir_gravedad(x, y)
    25
    26 -def leer(texto):
    27      """Utiliza el comando speak para 'leer' un texto como sonido.
    28
    29      :param texto: Cadena de texto a pronunciar.
    30      """
    31      # TODO: usar speak binding en lugar de subprocess.
    32      try:
    33          comando = subprocess.Popen(["espeak",  texto, "-v", "es-la"],
    34                  stdout=subprocess.PIPE,
    35                  stdin=subprocess.PIPE,
    36                  stderr=subprocess.PIPE)
    37      except OSError:
    38          pass
    39
    40 -def ocultar_puntero_del_mouse():
    41      """Oculta el puntero del mouse."""
    42      pilas.mundo.motor.ocultar_puntero_del_mouse()
    43
    44 -def mostrar_puntero_del_mouse():
    45      """Muestra el puntero del mouse."""
    46      pilas.mundo.motor.mostrar_puntero_del_mouse()
    47
    48 -def definir_modos(*k, **kv):
    49      """Define los modos de depuración."""
    50      pilas.mundo.motor.canvas.depurador.definir_modos(*k, **kv)
    51